==> intel-cmt-cat_23.08.orig.tar.xz: intel-cmt-cat-23.08/appqos_client/src/app/components/system-caps/rdt-iface/rdt-iface.component.ts <==
/*BSD LICENSE

Copyright(c) 2022 Intel Corporation. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
  * Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.
  * Neither the name of Intel Corporation nor the names of its
    contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.
    
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.*/

import { MatButtonToggleChange } from '@angular/material/button-toggle';
import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  Output,
  ViewEncapsulation,
} from '@angular/core';

import { RDTIface } from '../system-caps.model';

@Component({
  selector: 'app-rdt-iface',
  templateUrl: './rdt-iface.component.html',
  styleUrls: ['./rdt-iface.component.scss'],
  encapsulation: ViewEncapsulation.None,
  changeDetection: ChangeDetectionStrategy.OnPush,
})
/* Component used to show RDT interface details*/
export class RdtIfaceComponent {
  @Input() rdtIface!: RDTIface;
  @Output() changeEvent = new EventEmitter<MatButtonToggleChange>();

  onChangeIface(event: MatButtonToggleChange): void {
    this.changeEvent.emit(event);

    //Every time when we will click it will change state of Toggle butto value.
    //If response will failure then it will equal current state because rdtIface is not changed.
    //If response success then our rdtIface will updated and will eqaul new value.
    event.source.buttonToggleGroup.value = this.rdtIface.interface;
  }
}

==> intel-cmt-cat_25.04.orig.tar.xz: intel-cmt-cat-25.04/appqos_client/src/app/components/system-caps/rdt-iface/rdt-iface.component.ts <==
/*BSD LICENSE

Copyright(c) 2022 Intel Corporation. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
  * Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.
  * Neither the name of Intel Corporation nor the names of its
    contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.
    
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.*/

import { MatButtonToggleChange } from '@angular/material/button-toggle';
import {
  ChangeDetectionStrategy,
  Component,
  EventEmitter,
  Input,
  Output,
  ViewEncapsulation,
} from '@angular/core';

import { RDTIface } from '../system-caps.model';

@Component({
  selector: 'app-rdt-iface',
  templateUrl: './rdt-iface.component.html',
  styleUrls: ['./rdt-iface.component.scss'],
  encapsulation: ViewEncapsulation.None,
  changeDetection: ChangeDetectionStrategy.OnPush,
})
/* Component used to show RDT interface details*/
export class RdtIfaceComponent {
  @Input() rdtIface!: RDTIface;
  @Output() changeEvent = new EventEmitter<MatButtonToggleChange>();

  onChangeIface(event: MatButtonToggleChange): void {
    this.changeEvent.emit(event);

    //Every time when we will click it will change state of Toggle butto value.
    //If response will failure then it will equal current state because rdtIface is not changed.
    //If response success then our rdtIface will updated and will equal new value.
    event.source.buttonToggleGroup.value = this.rdtIface.interface;
  }
}
